# Contributing

The [Makefile](./Makefile) offers various helper commands:

```shell
make help
```

Make sure to:

1. Fork
2. Clone your fork
3. Create a branch
4. Commit changes
5. Submit your PR

See [GitHub flow](https://docs.github.com/en/get-started/quickstart/github-flow) for more about the contribution process.
